import 'package:tailor/tailor.dart' show TailorDB, join, File, Directory;
import 'package:instant/instant.dart';
import 'package:hive/hive.dart';

void main() {
  var tailor =
      TailorDB(file: File(join(Directory.current.path, 'test', 'db.json')));
  tailor.clear();

  var sw = InstantStopwatch()..play();
  for (var i = 0; i < 10000; i++) {
    tailor.add(key: 'Key: $i', value: 'Value: $i');
  }
  tailor.writeCache();
  var tailortime = sw.stopwatchInMilliseconds;
  print('Tailor Writes: $tailortime ms');

  sw.reset();
  sw.play();
  for (var i = 0; i < 10000; i++) {
    tailor.get(key: 'Key: $i');
  }
  var tailortime2 = sw.stopwatchInMilliseconds;
  print('Tailor Reads: $tailortime2 ms');

  sw.reset();
  sw.play();
  for (var i = 0; i < 10000; i++) {
    tailor.remove(key: 'Key: $i');
  }
  tailor.writeCache();
  var tailortime3 = sw.stopwatchInMilliseconds;
  print('Tailor Deletes: $tailortime3 ms');
  sw.reset();

  dohive();
}

void dohive() async {
  Hive.init(join(Directory.current.path, 'test'));
  var hive = await Hive.openBox('testdb');
  await hive.clear();

  var sw = InstantStopwatch()..play();
  for (var i = 0; i < 10000; i++) {
    await hive.put('Key: $i', 'Value: $i');
  }
  var hivetime = sw.stopwatchInMilliseconds;
  print('Hive Writes: $hivetime ms');

  sw.reset();
  sw.play();
  for (var i = 0; i < 10000; i++) {
    hive.get('Key: $i');
  }
  var hivetime2 = sw.stopwatchInMilliseconds;
  print('Hive Reads: $hivetime2 ms');

  sw.reset();
  sw.play();
  for (var i = 0; i < 10000; i++) {
    await hive.delete('Key: $i');
  }
  var hivetime3 = sw.stopwatchInMilliseconds;
  print('Hive Deletes: $hivetime3 ms');
}
